==> polymer-core-0.9.19+1.21.1-sources.jar: eu/pb4/polymer/core/mixin/client/compat/emi_EmiScreenManager.java <==
package eu.pb4.polymer.core.mixin.client.compat;

import com.llamalad7.mixinextras.sugar.Local;
import dev.emi.emi.api.stack.EmiStack;
import dev.emi.emi.screen.EmiScreenManager;
import eu.pb4.polymer.core.api.item.PolymerItemUtils;
import eu.pb4.polymer.core.impl.client.compat.CompatUtils;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Pseudo;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import java.util.ArrayList;
import java.util.Map;
import java.util.Map.Entry;
import net.minecraft.class_1799;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_5625;

@Pseudo
@Mixin(EmiScreenManager.class)
public class emi_EmiScreenManager {
    @Shadow private static class_310 client;

    @Inject(method = "give", at = @At(value = "INVOKE", target = "Lnet/minecraft/registry/Registry;getId(Ljava/lang/Object;)Lnet/minecraft/util/Identifier;"), require = 0, cancellable = true)
    private static void polymerCore$replaceWithServerItem(EmiStack eStack, int amount, int mode, CallbackInfoReturnable<Boolean> cir, @Local(ordinal = 0) class_1799 stack) {
        try {
            if (CompatUtils.isServerSide(stack)) {
                var id = PolymerItemUtils.getServerIdentifier(stack);
                var comp = CompatUtils.getBackingComponents(stack);
                var command = new StringBuilder("give @s " + id);
                if (comp != null && !comp.isEmpty()) {
                    command.append('[');
                    for (var e : comp.entrySet()) {
                        command.append(e.getKey().toString());
                        command.append('=');
                        command.append(new class_5625("", 0, new ArrayList<>()).method_32283(e.getValue()));
                    }
                    command.append(']');
                }

                if (command.length() > 256) {
                    command = new StringBuilder("give @s " + id);
                }
                if (amount != 1) {
                command.append(" ").append(amount);
                }
                client.field_1724.field_3944.method_45730(command.toString());
                cir.setReturnValue(true);
            }
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }
}

==> polymer-core-0.15.2+1.21.11-sources.jar: eu/pb4/polymer/core/mixin/client/compat/emi_EmiScreenManager.java <==
package eu.pb4.polymer.core.mixin.client.compat;

import com.llamalad7.mixinextras.sugar.Local;
import dev.emi.emi.api.stack.EmiStack;
import dev.emi.emi.screen.EmiScreenManager;
import eu.pb4.polymer.core.api.item.PolymerItemUtils;
import eu.pb4.polymer.core.impl.client.compat.CompatUtils;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Pseudo;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import java.util.ArrayList;
import net.minecraft.class_1799;
import net.minecraft.class_310;
import net.minecraft.class_5625;

@Pseudo
@Mixin(EmiScreenManager.class)
public class emi_EmiScreenManager {
    @Shadow private static class_310 client;

    @Inject(method = "give", at = @At(value = "INVOKE", target = "Lnet/minecraft/core/Registry;getKey(Ljava/lang/Object;)Lnet/minecraft/resources/Identifier;"), require = 0, cancellable = true)
    private static void polymerCore$replaceWithServerItem(EmiStack eStack, int amount, int mode, CallbackInfoReturnable<Boolean> cir, @Local(ordinal = 0) class_1799 stack) {
        try {
            if (CompatUtils.isServerSide(stack)) {
                var id = PolymerItemUtils.getServerIdentifier(stack);
                var comp = CompatUtils.getBackingComponents(stack);
                var command = new StringBuilder("give @s " + id);
                if (comp != null && !comp.isEmpty()) {
                    command.append('[');
                    for (var e : comp.entrySet()) {
                        command.append(e.getKey().toString());
                        command.append('=');
                        command.append(new class_5625("", 0, new ArrayList<>()).method_32283(e.getValue()));
                    }
                    command.append(']');
                }

                if (command.length() > 256) {
                    command = new StringBuilder("give @s " + id);
                }
                if (amount != 1) {
                command.append(" ").append(amount);
                }
                client.field_1724.field_3944.method_45730(command.toString());
                cir.setReturnValue(true);
            }
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }
}
